JoinPoint and related types.
A joinpoint represents a specific point in program execution where an aspect can be applied, such as a function call.
Structs
- Join
Point - Information about a specific point in program execution.
- Location
- Source code location information.
- Proceeding
Join Point - A proceeding joinpoint that can be used in “around” advice.